# ShowFile

<p align="center">
   <a href="https://github.com/wasi-master/showfile/graphs/contributors"><img src="https://img.shields.io/github/contributors/wasi-master/showfile.svg?style=flat" alt="Contributors"></a>
   <a href="https://github.com/wasi-master/showfile/network/members"><img src="https://img.shields.io/github/forks/wasi-master/showfile.svg?style=flat" alt="Forks"></a>
   <a href="https://github.com/wasi-master/showfile/stargazers"><img src="https://img.shields.io/github/stars/wasi-master/showfile.svg?style=flat" alt="Stargazers"></a>
   <a href="https://github.com/wasi-master/showfile/issues"><img src="https://img.shields.io/github/issues/wasi-master/showfile.svg?style=flat" alt="Issues"></a>
   <a href="https://github.com/wasi-master/showfile/blob/master/LICENSE"><img src="https://img.shields.io/github/license/wasi-master/showfile.svg?style=flat" alt="MIT License"></a>
   <a href="https://saythanks.io/to/arianmollik323@gmail.com"><img src="https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg" alt="Say Thanke"></a>
   <a href="https://pypistats.org/packages/showfile"><img src="https://img.shields.io/pypi/dm/showfile.svg?style=flat" alt="Downloads last Month"></a>
   <a href="https://pypistats.org/packages/showfile"><img src="https://img.shields.io/pypi/dw/showfile.svg?style=flat" alt="Downloads last Week"></a>
   <a href="https://pypistats.org/packages/showfile"><img src="https://img.shields.io/pypi/dd/showfile.svg?style=flat" alt="Downloads last Day"></a>
   <a href="https://pypi.org/project/showfile/#history"><img src="https://img.shields.io/pypi/v/showfile.svg" alt="Version"></a>
   <a href="https://github.com/wasi-master/showfile/actions/workflows/python-publish.yml"><img src="https://img.shields.io/github/workflow/status/wasi-master/showfile/Upload%20Python%20Package.svg?label=build" alt="Build"></a>
   <a href="https://github.com/psf/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black"></a>
</p>

A tool to show files with their proper syntax highlighting in the console

- 🌟 Supports Over [250 languages](https://pygments.org/languages/)
- 🚀 Blazingly Fast
- 👶 Extremely Easy to Use
- 🤖 Automatically detects File Types
- 😏 Really Lightweight (3.55 KB)
- 😍 Beautiful Syntax Highlighting using the [Monokai Pro](https://monokai.pro) theme

[View Demo](https://wasi-master.github.io/showfile/demo.html)

## Installation

First make sure you have [python](https://python.org) installed and added to path then run the following command

```sh
python -m pip install showfile
```

## Usage

To show the contents of a file simply use

```sh
showfile file.py
```

[![python.gif](https://raw.githubusercontent.com/wasi-master/showfile/main/demos/gifs/python.gif)](demos/files/demo.py)
